<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Kids Education Pro
 * @since Kids Education Pro 1.0
 */

if ( ! function_exists( 'kids_education_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Kids Education Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'kids_education_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'kids_education_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Kids Education Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'kids_education_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'kids_education_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Kids Education Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'kids_education_pro_theme_options[pagination_enable]' )->value();
	}
endif;

if ( ! function_exists( 'kids_education_pro_is_main_slider_active' ) ) :
	/**
	 * Check if main slider is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_main_slider_active( $control ) {

		return ( 'static-frontpage' == $control->manager->get_setting( 'kids_education_pro_theme_options[enable_main_slider]' )->value() );
	}
endif;

if ( ! function_exists( 'kids_education_pro_is_main_slider_demo_not_active' ) ) :
	/**
	 * Check if Main Slider Select type is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_main_slider_demo_not_active( $control ) {
		if ( ( kids_education_pro_is_main_slider_active( $control ) ) && ( 'demo' != $control->manager->get_setting( 'kids_education_pro_theme_options[main_slider_type]' )->value() ) )
			return true;

		return false;
	}
endif;


if ( ! function_exists( 'kids_education_pro_is_main_slider_content_as_category' ) ) :
	/**
	 * Check if Main Slider Category type is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_main_slider_content_as_category( $control ) {
		if ( ( kids_education_pro_is_main_slider_active( $control ) ) && ( 'category' == $control->manager->get_setting( 'kids_education_pro_theme_options[main_slider_type]' )->value() ) )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'kids_education_pro_is_main_slider_content_as_post' ) ) :
	/**
	 * Check if Main Slider Post type is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_main_slider_content_as_post( $control ) {
		if ( ( kids_education_pro_is_main_slider_active( $control ) ) && ( 'post' == $control->manager->get_setting( 'kids_education_pro_theme_options[main_slider_type]' )->value() ) )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'kids_education_pro_is_main_slider_content_as_page' ) ) :
	/**
	 * Check if Main Slider page type is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_main_slider_content_as_page( $control ) {
		if ( ( kids_education_pro_is_main_slider_active( $control ) ) && ( 'page' == $control->manager->get_setting( 'kids_education_pro_theme_options[main_slider_type]' )->value() ) )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'kids_education_pro_is_featured_active' ) ) :
	/**
	 * Check if main slider is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_featured_active( $control ) {

		return ( 'static-frontpage' == $control->manager->get_setting( 'kids_education_pro_theme_options[enable_featured]' )->value() );
	}
endif;


if ( ! function_exists( 'kids_education_pro_is_featured_content_as_category' ) ) :
	/**
	 * Check if Main Slider Category type is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_featured_content_as_category( $control ) {
		if ( ( kids_education_pro_is_featured_active( $control ) ) && ( 'category' == $control->manager->get_setting( 'kids_education_pro_theme_options[featured_type]' )->value() ) )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'kids_education_pro_is_featured_content_as_post' ) ) :
	/**
	 * Check if Main Slider Post type is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_featured_content_as_post( $control ) {
		if ( ( kids_education_pro_is_featured_active( $control ) ) && ( 'post' == $control->manager->get_setting( 'kids_education_pro_theme_options[featured_type]' )->value() ) )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'kids_education_pro_is_featured_content_as_page' ) ) :
	/**
	 * Check if Main Slider page type is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_featured_content_as_page( $control ) {
		if ( ( kids_education_pro_is_featured_active( $control ) ) && ( 'page' == $control->manager->get_setting( 'kids_education_pro_theme_options[featured_type]' )->value() ) )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'kids_education_pro_is_recent_post_active' ) ) :
	/**
	 * Check if main slider is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_recent_post_active( $control ) {

		return ( 'static-frontpage' == $control->manager->get_setting( 'kids_education_pro_theme_options[enable_recent_post]' )->value() );
	}
endif;


if ( ! function_exists( 'kids_education_pro_is_recent_post_content_as_category' ) ) :
	/**
	 * Check if Main Slider Category type is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_recent_post_content_as_category( $control ) {
		if ( ( kids_education_pro_is_recent_post_active( $control ) ) && ( 'category' == $control->manager->get_setting( 'kids_education_pro_theme_options[recent_post_type]' )->value() ) )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'kids_education_pro_is_recent_post_content_as_post' ) ) :
	/**
	 * Check if Main Slider Post type is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_recent_post_content_as_post( $control ) {
		if ( ( kids_education_pro_is_recent_post_active( $control ) ) && ( 'post' == $control->manager->get_setting( 'kids_education_pro_theme_options[recent_post_type]' )->value() ) )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'kids_education_pro_is_recent_post_content_as_page' ) ) :
	/**
	 * Check if Main Slider page type is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_recent_post_content_as_page( $control ) {
		if ( ( kids_education_pro_is_recent_post_active( $control ) ) && ( 'page' == $control->manager->get_setting( 'kids_education_pro_theme_options[recent_post_type]' )->value() ) )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'kids_education_pro_is_popular_active' ) ) :
	/**
	 * Check if main slider is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_popular_active( $control ) {

		return ( 'static-frontpage' == $control->manager->get_setting( 'kids_education_pro_theme_options[enable_popular]' )->value() );
	}
endif;


if ( ! function_exists( 'kids_education_pro_is_popular_content_as_category' ) ) :
	/**
	 * Check if Main Slider Category type is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_popular_content_as_category( $control ) {
		if ( ( kids_education_pro_is_popular_active( $control ) ) && ( 'category' == $control->manager->get_setting( 'kids_education_pro_theme_options[popular_type]' )->value() ) )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'kids_education_pro_is_popular_content_as_post' ) ) :
	/**
	 * Check if Main Slider Post type is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_popular_content_as_post( $control ) {
		if ( ( kids_education_pro_is_popular_active( $control ) ) && ( 'post' == $control->manager->get_setting( 'kids_education_pro_theme_options[popular_type]' )->value() ) )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'kids_education_pro_is_popular_content_as_page' ) ) :
	/**
	 * Check if Main Slider page type is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_popular_content_as_page( $control ) {
		if ( ( kids_education_pro_is_popular_active( $control ) ) && ( 'page' == $control->manager->get_setting( 'kids_education_pro_theme_options[popular_type]' )->value() ) )
			return true;

		return false;
	}
endif;

// Active callback for info text section. 
if ( ! function_exists( 'kids_education_pro_is_about_active' ) ) :
	/**
	 * Check if info content is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_about_active( $control ) {
		return ( 'static-frontpage' == $control->manager->get_setting( 'kids_education_pro_theme_options[enable_about_content]' )->value() );
	}
endif;


if ( ! function_exists( 'kids_education_pro_is_about_as_page' ) ) :
	/**
	 * Check if page type is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_about_as_page( $control ) {
		if ( ( kids_education_pro_is_about_active( $control ) ) && ( 'page' == $control->manager->get_setting( 'kids_education_pro_theme_options[about_type]' )->value() ) )
			return true;

		return false;
	}
endif;

// Active callback for info text section. 
if ( ! function_exists( 'kids_education_pro_is_info_content_active' ) ) :
	/**
	 * Check if info content is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_info_content_active( $control ) {
		return ( 'static-frontpage' == $control->manager->get_setting( 'kids_education_pro_theme_options[enable_info_content]' )->value() );
	}
endif;


if ( ! function_exists( 'kids_education_pro_is_info_content_as_page' ) ) :
	/**
	 * Check if page type is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_info_content_as_page( $control ) {
		if ( ( kids_education_pro_is_info_content_active( $control ) ) && ( 'page' == $control->manager->get_setting( 'kids_education_pro_theme_options[info_content_type]' )->value() ) )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'kids_education_pro_is_info_content_background_property_image' ) ) :
	/**
	 * Check if background image is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_info_content_background_property_image( $control ) {
		if ( ( kids_education_pro_is_info_content_as_page( $control ) ) && ( 'background_image' == $control->manager->get_setting( 'kids_education_pro_theme_options[info_content_background_property]' )->value() ) )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'kids_education_pro_is_info_content_background_property_color' ) ) :
	/**
	 * Check if background color is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_info_content_background_property_color( $control ) {
		if ( ( kids_education_pro_is_info_content_as_page( $control ) ) && ( 'background_color' == $control->manager->get_setting( 'kids_education_pro_theme_options[info_content_background_property]' )->value() ) )
			return true;

		return false;
	}
endif;

// Active callback for search course section. 
if ( ! function_exists( 'kids_education_pro_is_search_course_active' ) ) :
	/**
	 * Check if search course is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_search_course_active( $control ) {
		return ( 'static-frontpage' == $control->manager->get_setting( 'kids_education_pro_theme_options[search_course_enable]' )->value() );
	}
endif;

// Active callback for search section
if ( ! function_exists( 'kids_education_pro_is_search_course_background_property_image' ) ) :
	/**
	 * Check if background image is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_search_course_background_property_image( $control ) {
		if ( kids_education_pro_is_search_course_active( $control ) && 'background_image' == $control->manager->get_setting( 'kids_education_pro_theme_options[search_course_background_property]' )->value() )
			return true;

		return false;
	}
endif;

// Active callback for search section
if ( ! function_exists( 'kids_education_pro_is_search_course_background_property_color' ) ) :
	/**
	 * Check if background color is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_search_course_background_property_color( $control ) {
		if ( kids_education_pro_is_search_course_active( $control ) && 'background_color' == $control->manager->get_setting( 'kids_education_pro_theme_options[search_course_background_property]' )->value() )
			return true;

		return false;
	}
endif;

// Active callback for features section
if ( ! function_exists( 'kids_education_pro_is_features_active' ) ) :
	/**
	 * Check if features content is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_features_active( $control ) {
		return ( 'static-frontpage' == $control->manager->get_setting( 'kids_education_pro_theme_options[features_enable]' )->value() );
	}
endif;

if ( ! function_exists( 'kids_education_pro_is_features_content_demo_inactive' ) ) :
	/**
	 * Check if features section type is not demo.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_features_content_demo_inactive( $control ) {
		if ( ( kids_education_pro_is_features_active( $control ) ) && ( 'demo' != $control->manager->get_setting( 'kids_education_pro_theme_options[features_section_type]' )->value() ) )
			return true;

		return false;
	}
endif;



if ( ! function_exists( 'kids_education_pro_is_features_content_type_page_active' ) ) :
	/**
	 * Check if features section type is page.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_features_content_type_page_active( $control ) {
		$content_type = $control->manager->get_setting( 'kids_education_pro_theme_options[features_section_type]' )->value();
		if ( ( kids_education_pro_is_features_active( $control ) ) && ( 'page' == $content_type ) )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'kids_education_pro_is_features_content_type_as_category' ) ) :
	/**
	 * Check if features section type is category.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_features_content_type_as_category( $control ) {
		$content_type = $control->manager->get_setting( 'kids_education_pro_theme_options[features_section_type]' )->value();
		if ( ( kids_education_pro_is_features_active( $control ) ) && ( 'category' == $content_type ) )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'kids_education_pro_is_features_background_property_image' ) ) :
	/**
	 * Check if background image is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_features_background_property_image( $control ) {
		if ( kids_education_pro_is_features_content_demo_inactive( $control ) && 'background_image' == $control->manager->get_setting( 'kids_education_pro_theme_options[features_background_property]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'kids_education_pro_is_features_background_property_color' ) ) :
	/**
	 * Check if background color is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_features_background_property_color( $control ) {
		if ( kids_education_pro_is_features_content_demo_inactive( $control ) && 'background_color' == $control->manager->get_setting( 'kids_education_pro_theme_options[features_background_property]' )->value() )
			return true;

		return false;
	}
endif;

// Active callback for counter section
if ( ! function_exists( 'kids_education_pro_is_counter_active' ) ) :
	/**
	 * Check if counter content is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_counter_active( $control ) {
		return ( 'static-frontpage' == $control->manager->get_setting( 'kids_education_pro_theme_options[counter_enable]' )->value() );
	}
endif;

if ( ! function_exists( 'kids_education_pro_is_counter_content_demo_inactive' ) ) :
	/**
	 * Check if counter section type is not demo.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_counter_content_demo_inactive( $control ) {
		$content_type = $control->manager->get_setting( 'kids_education_pro_theme_options[counter_content_type]' )->value();
		if ( ( kids_education_pro_is_counter_active( $control ) ) && ( 'demo' != $content_type ) )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'kids_education_pro_is_counter_background_property_image' ) ) :
	/**
	 * Check if background image is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_counter_background_property_image( $control ) {
		return ( kids_education_pro_is_counter_content_demo_inactive( $control ) && 'background_image' == $control->manager->get_setting( 'kids_education_pro_theme_options[counter_background_property]' )->value() );
	}
endif;

if ( ! function_exists( 'kids_education_pro_is_counter_background_property_color' ) ) :
	/**
	 * Check if background color is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_counter_background_property_color( $control ) {
		return ( kids_education_pro_is_counter_content_demo_inactive( $control ) && 'background_color' == $control->manager->get_setting( 'kids_education_pro_theme_options[counter_background_property]' )->value() );
	}
endif;


// Active callback for gallery section
if ( ! function_exists( 'kids_education_pro_is_gallery_active' ) ) :
	/**
	 * Check if gallery content is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_gallery_active( $control ) {
		return ( 'static-frontpage' == $control->manager->get_setting( 'kids_education_pro_theme_options[gallery_enable]' )->value() );
	}
endif;

if ( ! function_exists( 'kids_education_pro_gallery_source_demo_inactive' ) ) :
	/**
	 * Check if gallery source  is not demo.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_gallery_source_demo_inactive( $control ) {
		$content_type =  $control->manager->get_setting( 'kids_education_pro_theme_options[gallery_source]' )->value();
		if ( ( kids_education_pro_is_gallery_active( $control ) ) && ( 'demo' != $content_type ) )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'kids_education_pro_is_gallery_background_property_image' ) ) :
	/**
	 * Check if background image is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_gallery_background_property_image( $control ) {
		$background_property =  $control->manager->get_setting( 'kids_education_pro_theme_options[gallery_background_property]' )->value();
		if ( kids_education_pro_gallery_source_demo_inactive( $control ) && ( 'background_image' == $background_property ) )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'kids_education_pro_is_gallery_background_property_color' ) ) :
	/**
	 * Check if background color is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_gallery_background_property_color( $control ) {
		$background_property =  $control->manager->get_setting( 'kids_education_pro_theme_options[gallery_background_property]' )->value();
		if ( kids_education_pro_gallery_source_demo_inactive( $control ) && ( 'background_color' == $background_property ) )
			return true;

		return false;
	}
endif;

// Active callback for category blog section
if ( ! function_exists( 'kids_education_pro_is_category_blog_section_active' ) ) :
	/**
	 * Check if category blog content is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_category_blog_section_active( $control ) {
		return ( 'static-frontpage' == $control->manager->get_setting( 'kids_education_pro_theme_options[category_blog_enable]' )->value() );
	}
endif;

if ( ! function_exists( 'kids_education_pro_is_category_blog_content_demo_inactive' ) ) :
	/**
	 * Check if category blog source is not demo.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_category_blog_content_demo_inactive( $control ) {
		$content_type =  $control->manager->get_setting( 'kids_education_pro_theme_options[category_blog_content_type]' )->value();
		if ( ( kids_education_pro_is_category_blog_section_active( $control ) ) && ( 'demo' != $content_type ) )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'kids_education_pro_is_category_blog_background_property_image' ) ) :
	/**
	 * Check if background image is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_category_blog_background_property_image( $control ) {
		$background_property =  $control->manager->get_setting( 'kids_education_pro_theme_options[category_blog_background_property]' )->value();
		if ( ( kids_education_pro_is_category_blog_content_demo_inactive( $control ) ) && ( 'background_image' == $background_property ) )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'kids_education_pro_is_category_blog_background_property_color' ) ) :
	/**
	 * Check if background color is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_category_blog_background_property_color( $control ) {
		$background_property =  $control->manager->get_setting( 'kids_education_pro_theme_options[category_blog_background_property]' )->value();
		if ( ( kids_education_pro_is_category_blog_content_demo_inactive( $control ) ) && ( 'background_color' == $background_property ) )
			return true;

		return false;
	}
endif;


// Active callback for recent section
if ( ! function_exists( 'kids_education_pro_is_recent_section_active' ) ) :
	/**
	 * Check if recent content is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_recent_section_active( $control ) {
		return ( 'static-frontpage' == $control->manager->get_setting( 'kids_education_pro_theme_options[recent_enable]' )->value() );
	}
endif;

if ( ! function_exists( 'kids_education_pro_is_recent_section_background_property_image' ) ) :
	/**
	 * Check if background image is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_recent_section_background_property_image( $control ) {
		return ( kids_education_pro_is_recent_section_active( $control ) && 'background_image' == $control->manager->get_setting( 'kids_education_pro_theme_options[recent_background_property]' )->value() );
	}
endif;

if ( ! function_exists( 'kids_education_pro_is_recent_section_background_property_color' ) ) :
	/**
	 * Check if background color is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_recent_section_background_property_color( $control ) {
		return ( kids_education_pro_is_recent_section_active( $control ) && 'background_color' == $control->manager->get_setting( 'kids_education_pro_theme_options[recent_background_property]' )->value() );
	}
endif;


// Active callback for testimonial section
if ( ! function_exists( 'kids_education_pro_is_testimonial_section_active' ) ) :
	/**
	 * Check if testimonial content is active.

	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */

	function kids_education_pro_is_testimonial_section_active( $control ) {
		return ( 'static-frontpage' == $control->manager->get_setting( 'kids_education_pro_theme_options[testimonial_enable]' )->value() );
	}
endif;

// Active callback for testimonial post
if ( ! function_exists( 'kids_education_pro_is_testimonial_post_active' ) ) :
	/**
	 * Check if testimonial content is active.

	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */

	function kids_education_pro_is_testimonial_post_active( $control ) {
		return ( kids_education_pro_is_testimonial_section_active( $control ) && 'tp-testimonial' == $control->manager->get_setting( 'kids_education_pro_theme_options[testimonial_content_type]' )->value()  );
	}
endif;


if ( ! function_exists( 'kids_education_pro_is_testimonial_background_property_image' ) ) :
	/**
	 * Check if background image is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */

	function kids_education_pro_is_testimonial_background_property_image( $control ) {
		return ( kids_education_pro_is_testimonial_post_active( $control ) && 'background_image' == $control->manager->get_setting( 'kids_education_pro_theme_options[testimonial_background_property]' )->value()  );
	}
endif;


if ( ! function_exists( 'kids_education_pro_is_testimonial_background_property_color' ) ) :
	/**
	 * Check if background color is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */

	function kids_education_pro_is_testimonial_background_property_color( $control ) {
		return ( kids_education_pro_is_testimonial_post_active( $control ) && 'background_color' == $control->manager->get_setting( 'kids_education_pro_theme_options[testimonial_background_property]' )->value()  );
	}
endif;


// Active callback for team section
if ( ! function_exists( 'kids_education_pro_is_team_section_active' ) ) :
	/**
	 * Check if team content is active.

	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */

	function kids_education_pro_is_team_section_active( $control ) {
		return ( 'static-frontpage' == $control->manager->get_setting( 'kids_education_pro_theme_options[team_enable]' )->value() );
	}
endif;

// Active callback for team section is post
if ( ! function_exists( 'kids_education_pro_is_team_section_demo_not_active' ) ) :
	/**
	 * Check if team content demo is not active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */

	function kids_education_pro_is_team_section_demo_not_active( $control ) {
		return ( kids_education_pro_is_team_section_active( $control ) && 'demo' != $control->manager->get_setting( 'kids_education_pro_theme_options[team_content_type]' )->value() );
	}
endif;

// Active callback for team section is post
if ( ! function_exists( 'kids_education_pro_is_team_section_post' ) ) :
	/**
	 * Check if team content is post.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */

	function kids_education_pro_is_team_section_post( $control ) {
		return ( kids_education_pro_is_team_section_active( $control )  && 'post' == $control->manager->get_setting( 'kids_education_pro_theme_options[team_content_type]' )->value() );
	}
endif;

// Active callback for team section is category
if ( ! function_exists( 'kids_education_pro_is_team_section_category' ) ) :
	/**
	 * Check if team content is category.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */

	function kids_education_pro_is_team_section_category( $control ) {
		return ( kids_education_pro_is_team_section_active( $control )  && 'category' == $control->manager->get_setting( 'kids_education_pro_theme_options[team_content_type]' )->value() );
	}
endif;

if ( ! function_exists( 'kids_education_pro_is_team_background_property_image' ) ) :
	/**
	 * Check if background image is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */

	function kids_education_pro_is_team_background_property_image( $control ) {
		return ( kids_education_pro_is_team_section_demo_not_active( $control )  && 'background_image' == $control->manager->get_setting( 'kids_education_pro_theme_options[team_background_property]' )->value() );
	}
endif;

if ( ! function_exists( 'kids_education_pro_is_team_background_property_color' ) ) :
	/**
	 * Check if background color is active.
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */

	function kids_education_pro_is_team_background_property_color( $control ) {
		return ( kids_education_pro_is_team_section_demo_not_active( $control )  && 'background_color' == $control->manager->get_setting( 'kids_education_pro_theme_options[team_background_property]' )->value() );
	}
endif;



/**
 * Custom page template active callback 
 *
 * @since Kids Education Pro 1.0
 */

// Active callback for contact address 
if ( ! function_exists( 'kids_education_pro_is_contact_address_active' ) ) :
	/**
	 * Check if contact address is active.
	 */

	function kids_education_pro_is_contact_address_active( $control ) {
		return ( $control->manager->get_setting( 'kids_education_pro_theme_options[enable_address_block]' )->value() );
	}
endif;

// Active callback for contact form
if ( ! function_exists( 'kids_education_pro_is_contact_form_active' ) ) :
	/**
	 * Check if contact form is active.
	 */

	function kids_education_pro_is_contact_form_active( $control ) {
		return ( $control->manager->get_setting( 'kids_education_pro_theme_options[enable_contact_form]' )->value() );
	}
endif;

// Active callback for contact map
if ( ! function_exists( 'kids_education_pro_is_contact_map_active' ) ) :
	/**
	 * Check if contact map is active.
	 */

	function kids_education_pro_is_contact_map_active( $control ) {
		return ( $control->manager->get_setting( 'kids_education_pro_theme_options[enable_contact_map]' )->value() );
	}
endif;

// Active callback for map type
if ( ! function_exists( 'kids_education_pro_contact_map_embed' ) ) :
	/**
	 * Check if map content content type embed is selected
	 */

	function kids_education_pro_contact_map_embed( $control ) {
		$map_option = $control->manager->get_setting( 'kids_education_pro_theme_options[map_type_option]' )->value();

		if ( ( kids_education_pro_is_contact_map_active( $control ) ) && ( 'embed' == $map_option ) )
			return true;

		return false;
	}
endif;

// Active callback for map type
if ( ! function_exists( 'kids_education_pro_contact_map_shortcode' ) ) :
	/**
	 * Check if map content content type shortcode is selected
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_contact_map_shortcode( $control ) {
		$map_option = $control->manager->get_setting( 'kids_education_pro_theme_options[map_type_option]' )->value();

		if ( ( kids_education_pro_is_contact_map_active( $control ) ) && ( 'shortcode' == $map_option ) )
			return true;

		return false;
	}
endif;

// Active callback for post navigation
if ( ! function_exists( 'kids_education_pro_enable_post_navigation' ) ) :
	/**
	 * Check if post navigation is enabled.
	 */

	function kids_education_pro_enable_post_navigation( $control ) {
		return ( $control->manager->get_setting( 'kids_education_pro_theme_options[post_navigation_enable]' )->value() );
	}
endif;

// Active callback for footer section
if ( ! function_exists( 'kids_education_pro_is_footer_background_property_image' ) ) :
	/**
	 * Check if post navigation is enabled.
	 */

	function kids_education_pro_is_footer_background_property_image( $control ) {
		return ( 'background_image' == $control->manager->get_setting( 'kids_education_pro_theme_options[footer_background_property]' )->value() );
	}
endif;

if ( ! function_exists( 'kids_education_pro_is_footer_background_property_color' ) ) :
	/**
	 * Check if post navigation is enabled.
	 */

	function kids_education_pro_is_footer_background_property_color( $control ) {
		return ( 'background_color' == $control->manager->get_setting( 'kids_education_pro_theme_options[footer_background_property]' )->value() );
	}
endif;

// Active callback for static homepage option
if ( ! function_exists( 'kids_education_pro_static_homepage_content_active' ) ) :
	/**
	 * Check if static homepage content is enabled
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_static_homepage_content_active( $control ) {
		return $control->manager->get_setting( 'kids_education_pro_theme_options[enable_frontpage_content]' )->value();
	}
endif;

if ( ! function_exists( 'kids_education_pro_is_static_homepage_background_property_image' ) ) :
	/**
	 * Check if static homepage background image is enabled
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_static_homepage_background_property_image( $control ) {
		if( kids_education_pro_static_homepage_content_active( $control )  &&  'background_image' == $control->manager->get_setting( 'kids_education_pro_theme_options[static_homepage_background_property]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'kids_education_pro_is_static_homepage_background_property_color' ) ) :
	/**
	 * Check if static homepage background color is enabled
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function kids_education_pro_is_static_homepage_background_property_color( $control ) {
		if( kids_education_pro_static_homepage_content_active( $control )  &&  'background_color' == $control->manager->get_setting( 'kids_education_pro_theme_options[static_homepage_background_property]' )->value() )
			return true;
		
		return false;
	}
endif;

