<?php
/**
 * Main Slider Customizer options
 *
 * @package Theme Palace
 * @subpackage Kids Education Pro
 * @since Kids Education Pro 1.0
 */


// Add Main Slider enable section
$wp_customize->add_section( 'kids_education_pro_main_slider_section', array(
	'title'             => esc_html__( 'Main Slider','kids-education-pro' ),
	'description'       => esc_html__( 'Main Slider section options. Recommended image size for slider is 1350px by 550px', 'kids-education-pro' ),
	'priority'			=> '10',
	'panel'             => 'kids_education_pro_sections_panel'
) );

// Add Main Slider enable setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[enable_main_slider]', array(
	'default'           => $options['enable_main_slider'],
	'sanitize_callback' => 'kids_education_pro_sanitize_select'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[enable_main_slider]', array(
	'label'             => esc_html__( 'Check To Enable', 'kids-education-pro' ),
	'section'           => 'kids_education_pro_main_slider_section',
	'type'              => 'select',
	'choices'			=> kids_education_pro_enable_disable_options(),
) );

// Add Main Slider content type setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[main_slider_type]', array(
	'default'           => $options['main_slider_type'],
	'sanitize_callback' => 'kids_education_pro_sanitize_select'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[main_slider_type]', array(
	'label'           	=> esc_html__( 'Content Type', 'kids-education-pro' ),
	'section'         	=> 'kids_education_pro_main_slider_section',
	'type'            	=> 'select',
	'active_callback' 	=> 'kids_education_pro_is_main_slider_active',
	'choices'         	=> array(
		'demo'			=> esc_html__( 'Demo','kids-education-pro'),
		'category'		=> esc_html__( 'Category', 'kids-education-pro' ),
		'post'			=> esc_html__( 'Post', 'kids-education-pro' ),
		'page'			=> esc_html__( 'Page', 'kids-education-pro')	
	)
) );

// Add slider effects setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[slider_content_effect]', array(
	'default'           => $options['slider_content_effect'],
	'sanitize_callback' => 'kids_education_pro_sanitize_select'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[slider_content_effect]', array(
	'label'           => esc_html__( 'Transition Effects', 'kids-education-pro' ),
	'section'         => 'kids_education_pro_main_slider_section',
	'type'            => 'select',
	'active_callback' => 'kids_education_pro_is_main_slider_demo_not_active',
	'choices'         => kids_education_pro_slider_effect(),
) );

// Add enable arrow controls setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[enable_slider_controls]', array(
	'default'           => $options['enable_slider_controls'],
	'sanitize_callback' => 'kids_education_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[enable_slider_controls]', array(
	'label'           => esc_html__( 'Enable Arrow Controls', 'kids-education-pro' ),
	'section'         => 'kids_education_pro_main_slider_section',
	'type'            => 'checkbox',
	'active_callback' => 'kids_education_pro_is_main_slider_demo_not_active',
) );

// Add enable slider dragable setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[enable_slider_dragable]', array(
	'default'           => $options['enable_slider_dragable'],
	'sanitize_callback' => 'kids_education_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[enable_slider_dragable]', array(
	'label'           => esc_html__( 'Slider Dragable', 'kids-education-pro' ),
	'section'         => 'kids_education_pro_main_slider_section',
	'type'            => 'checkbox',
	'active_callback' => 'kids_education_pro_is_main_slider_demo_not_active',
) );

// Add enable slider pause on hover setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[slider_pause_on_hover]', array(
	'default'           => $options['slider_pause_on_hover'],
	'sanitize_callback' => 'kids_education_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[slider_pause_on_hover]', array(
	'label'           => esc_html__( 'Pause On Hover', 'kids-education-pro' ),
	'section'         => 'kids_education_pro_main_slider_section',
	'type'            => 'checkbox',
	'active_callback' => 'kids_education_pro_is_main_slider_demo_not_active',
) );

// Add slider divider disable setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[slider_divider_enable]', array(
	'default'           => $options['slider_divider_enable'],
	'sanitize_callback' => 'kids_education_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[slider_divider_enable]', array(
	'label'           => esc_html__( 'Enable slider divider', 'kids-education-pro' ),
	'section'         => 'kids_education_pro_main_slider_section',
	'type'            => 'checkbox',
	'active_callback' => 'kids_education_pro_is_main_slider_demo_not_active',
) );

// Add Main Slider number of posts setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[main_slider_no_of_posts]', array(
	'default'           => $options['main_slider_no_of_posts'],
	'validate_callback' => 'kids_education_pro_validate_no_of_main_slider',
	'sanitize_callback' => 'kids_education_pro_sanitize_number_range'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[main_slider_no_of_posts]', array(
	'label'           	=> esc_html__( 'Number Of Main Slider', 'kids-education-pro' ),
	'description'       => esc_html__( 'Notice: Please refresh after the number of slides is set to see the effects.', 'kids-education-pro' ),
	'section'         	=> 'kids_education_pro_main_slider_section',
	'type'            	=> 'number',
	'active_callback' 	=> 'kids_education_pro_is_main_slider_demo_not_active',
	'input_attrs'		=> array(
		'min'			=> '1',
		'max'			=> '10',
		'step'			=> '1',
		'style'			=> 'width:50px',
		),
) );

// Add Main Slider category drop-down setting and control
$wp_customize->add_setting( 'kids_education_pro_theme_options[main_slider_category_type]', array(
	'default'			=> $options['main_slider_category_type'],			
	'sanitize_callback'	=> 'kids_education_pro_sanitize_category_list',
) );

$wp_customize->add_control( new Kids_Education_Pro_Dropdown_Category_Control( $wp_customize, 'kids_education_pro_theme_options[main_slider_category_type]', array(
	'active_callback' 	=> 'kids_education_pro_is_main_slider_content_as_category',
	'label'           	=> esc_html__( 'Select Category', 'kids-education-pro' ),
	'section'         	=> 'kids_education_pro_main_slider_section',
	'type'            	=> 'dropdown-category',
 ) ) );


$value = kids_education_pro_get_theme_options();
$no_of_post = $value['main_slider_no_of_posts'];

for ( $i = 1; $i <= $no_of_post; $i++ ) {
	// Insert main slider  post id
	$wp_customize->add_setting( 'kids_education_pro_theme_options[main_slider_post_id_' . $i . ']', array(
		'sanitize_callback' => 'kids_education_pro_sanitize_number_range'
	) );

	$wp_customize->add_control( 'kids_education_pro_theme_options[main_slider_post_id_' . $i . ']', array(
		'label'             => esc_html__( 'Post id # ' , 'kids-education-pro' ) . $i,
		'section'           => 'kids_education_pro_main_slider_section',
		'input_attrs' 		=> array( 
			'style' 		=> 'width: 100px;',
			'min'			=> '1', 
			'placeholder'	=> esc_attr__( 'Post ID', 'kids-education-pro' ) ),
		'type'              => 'number',
		'active_callback'	=> 'kids_education_pro_is_main_slider_content_as_post'
	) );

	// Select main slider page
	$wp_customize->add_setting( 'kids_education_pro_theme_options[main_slider_page_id_' . $i . ']', array(
		'sanitize_callback' => 'kids_education_pro_sanitize_page'
	) );

	$wp_customize->add_control( 'kids_education_pro_theme_options[main_slider_page_id_' . $i . ']', array(
		'label'             => esc_html__( 'Select Page # ' , 'kids-education-pro' ) . $i,
		'section'           => 'kids_education_pro_main_slider_section',
		'active_callback'	=> 'kids_education_pro_is_main_slider_content_as_page',
		'type'              => 'dropdown-pages',
	) );

}

// Add learn more text setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[main_slider_learn_more_text]', array(
	'default'           => $options['main_slider_learn_more_text'],
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[main_slider_learn_more_text]', array(
	'label'           	=> esc_html__( 'Learn More Text', 'kids-education-pro' ),
	'description'		=> esc_html__( 'Leave empty to hide button', 'kids-education-pro' ),
	'section'         	=> 'kids_education_pro_main_slider_section',
	'active_callback' 	=> 'kids_education_pro_is_main_slider_demo_not_active',
));

$wp_customize->add_setting( 'kids_education_pro_theme_options[slider_excerpt]', array(
	'default'           => $options['slider_excerpt'],
	'validate_callback' => 'kids_education_pro_validate_no_of_main_slider',
	'sanitize_callback' => 'kids_education_pro_sanitize_number_range'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[slider_excerpt]', array(
	'label'           	=> esc_html__( 'Excerpt Lenght', 'kids-education-pro' ),
	'section'         	=> 'kids_education_pro_main_slider_section',
	'type'            	=> 'number',
	'active_callback' 	=> 'kids_education_pro_is_main_slider_demo_not_active',
) );