<?php
/**
 * Main recent_post Customizer options
 *
 * @package Theme Palace
 * @subpackage Kids Education Pro
 * @since Kids Education Pro 1.0
 */


// Add Main recent_post enable section
$wp_customize->add_section( 'kids_education_pro_recent_post_section', array(
	'title'             => esc_html__( 'Recent','kids-education-pro' ),
	'description'       => esc_html__( 'Recent section options. Recommended image size for recent_post is 1350px by 550px', 'kids-education-pro' ),
	'priority'			=> '10',
	'panel'             => 'kids_education_pro_sections_panel'
) );

// Add Main recent_post enable setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[enable_recent_post]', array(
	'default'           => $options['enable_recent_post'],
	'sanitize_callback' => 'kids_education_pro_sanitize_select'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[enable_recent_post]', array(
	'label'             => esc_html__( 'Check To Enable', 'kids-education-pro' ),
	'section'           => 'kids_education_pro_recent_post_section',
	'type'              => 'select',
	'choices'			=> kids_education_pro_enable_disable_options(),
) );

$wp_customize->add_setting( 'kids_education_pro_theme_options[recent_post_title]', array(
	'default'           => $options['recent_post_title'],
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[recent_post_title]', array(
	'label'           	=> esc_html__( 'Title', 'kids-education-pro' ),
	'section'         	=> 'kids_education_pro_recent_post_section',
	'type'            	=> 'text',
	'active_callback' 	=> 'kids_education_pro_is_recent_post_active',
) );

// Add Main recent_post content type setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[recent_post_type]', array(
	'default'           => $options['recent_post_type'],
	'sanitize_callback' => 'kids_education_pro_sanitize_select'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[recent_post_type]', array(
	'label'           	=> esc_html__( 'Content Type', 'kids-education-pro' ),
	'section'         	=> 'kids_education_pro_recent_post_section',
	'type'            	=> 'select',
	'active_callback' 	=> 'kids_education_pro_is_recent_post_active',
	'choices'         	=> array(
		'category'		=> esc_html__( 'Category', 'kids-education-pro' ),
		'post'			=> esc_html__( 'Post', 'kids-education-pro' ),
		'page'			=> esc_html__( 'Page', 'kids-education-pro')	
	)
) );

// Add Main recent_post number of posts setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[recent_post_no_of_posts]', array(
	'default'           => $options['recent_post_no_of_posts'],
	'validate_callback' => 'kids_education_pro_validate_no_of_recent_post',
	'sanitize_callback' => 'kids_education_pro_sanitize_number_range'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[recent_post_no_of_posts]', array(
	'label'           	=> esc_html__( 'Number Of recent_post Post', 'kids-education-pro' ),
	'description'       => esc_html__( 'Notice: Please refresh after the number of slides is set to see the effects.', 'kids-education-pro' ),
	'section'         	=> 'kids_education_pro_recent_post_section',
	'active_callback' 	=> 'kids_education_pro_is_recent_post_active',
	'type'            	=> 'number',
	'input_attrs'		=> array(
		'min'			=> '2',
		'max'			=> '10',
		'step'			=> '1',
		'style'			=> 'width:50px',
		),
) );

// Add Main recent_post category drop-down setting and control
$wp_customize->add_setting( 'kids_education_pro_theme_options[recent_post_category_type]', array(		
	'sanitize_callback'	=> 'kids_education_pro_sanitize_category_list',
) );

$wp_customize->add_control( new Kids_Education_Pro_Dropdown_Category_Control( $wp_customize, 'kids_education_pro_theme_options[recent_post_category_type]', array(
	'active_callback' 	=> 'kids_education_pro_is_recent_post_content_as_category',
	'label'           	=> esc_html__( 'Select Category', 'kids-education-pro' ),
	'section'         	=> 'kids_education_pro_recent_post_section',
	'type'            	=> 'dropdown-category',
 ) ) );


$value = kids_education_pro_get_theme_options();
$no_of_post = $value['recent_post_no_of_posts'];

for ( $i = 1; $i <= $no_of_post; $i++ ) {
	// Insert main recent_post  post id
	$wp_customize->add_setting( 'kids_education_pro_theme_options[recent_post_post_id_' . $i . ']', array(
		'sanitize_callback' => 'kids_education_pro_sanitize_number_range'
	) );

	$wp_customize->add_control( 'kids_education_pro_theme_options[recent_post_post_id_' . $i . ']', array(
		'label'             => esc_html__( 'Post id # ' , 'kids-education-pro' ) . $i,
		'section'           => 'kids_education_pro_recent_post_section',
		'input_attrs' 		=> array( 
			'style' 		=> 'width: 100px;',
			'min'			=> '1', 
			'placeholder'	=> esc_attr__( 'Post ID', 'kids-education-pro' ) ),
		'type'              => 'number',
		'active_callback'	=> 'kids_education_pro_is_recent_post_content_as_post'
	) );

	// Select main recent_post page
	$wp_customize->add_setting( 'kids_education_pro_theme_options[recent_post_page_id_' . $i . ']', array(
		'sanitize_callback' => 'kids_education_pro_sanitize_page'
	) );

	$wp_customize->add_control( 'kids_education_pro_theme_options[recent_post_page_id_' . $i . ']', array(
		'label'             => esc_html__( 'Select Page # ' , 'kids-education-pro' ) . $i,
		'section'           => 'kids_education_pro_recent_post_section',
		'active_callback'	=> 'kids_education_pro_is_recent_post_content_as_page',
		'type'              => 'dropdown-pages',
	) );
}


$wp_customize->add_setting( 'kids_education_pro_theme_options[ads_image]', array(
	'sanitize_callback' => 'esc_url_raw'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'kids_education_pro_theme_options[ads_image]',
    array(
		'label'           => esc_html__( 'Upload a background image', 'kids-education-pro' ),
		'description'     => esc_html__( 'Recommended background image size is 900*100 px', 'kids-education-pro' ),
		'section'         => 'kids_education_pro_recent_post_section',
		'active_callback' 	=> 'kids_education_pro_is_recent_post_active',
   )
));

$wp_customize->add_setting( 'kids_education_pro_theme_options[ads_url]', array(
	'sanitize_callback' => 'esc_url_raw'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[ads_url]', array(
	'label'           	=> esc_html__( 'Ads Url', 'kids-education-pro' ),
	'section'         	=> 'kids_education_pro_recent_post_section',
	'type'            	=> 'url',
	'active_callback' 	=> 'kids_education_pro_is_recent_post_active',
) );


$wp_customize->add_setting( 'kids_education_pro_theme_options[recent_post_excerpt]', array(
	'default'           => $options['recent_post_excerpt'],
	'sanitize_callback' => 'kids_education_pro_sanitize_number_range'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[recent_post_excerpt]', array(
	'label'           	=> esc_html__( 'Expcerpt Lenght', 'kids-education-pro' ),
	'section'         	=> 'kids_education_pro_recent_post_section',
	'active_callback' 	=> 'kids_education_pro_is_recent_post_active',
	'type'            	=> 'number',
) );