<?php
/**
 * Kids Education Pro Team Customizer options
 *
 * @package Theme Palace
 * @subpackage Kids Education Pro
 * @since Kids Education Pro 1.0
 */


// Add team enable section
$wp_customize->add_section( 'kids_education_pro_team', array(
	'title'             => esc_html__( 'Team','kids-education-pro' ),
	'description'       => esc_html__( 'Team section options.', 'kids-education-pro' ),
	'panel'             => 'kids_education_pro_sections_panel'
) );

// Add team enable setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[team_enable]', array(
	'default'           => $options['team_enable'],
	'sanitize_callback' => 'kids_education_pro_sanitize_select'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[team_enable]', array(
	'label'             => esc_html__( 'Enable on', 'kids-education-pro' ),
	'section'           => 'kids_education_pro_team',
	'type'              => 'select',
	'choices'           => kids_education_pro_enable_disable_options()
) );

// Add team title setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[team_title]', array(
	'default'           => $options['team_title'],
	'transport'         => 'postMessage',
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[team_title]', array(
	'label'             => esc_html__( 'Title', 'kids-education-pro' ),
	'section'           => 'kids_education_pro_team',
	'type'              => 'text',
	'active_callback'	=> 'kids_education_pro_is_team_section_active',
) );


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'kids_education_pro_theme_options[team_title]', array(
		'selector'            => '#team-members h2.entry-title',
		'render_callback'     => 'kids_education_pro_customize_partial_team_title',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Add team description setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[team_description]', array(
	'default'           => $options['team_description'],
	'transport'         => 'postMessage',
	'sanitize_callback' => 'esc_textarea'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[team_description]', array(
	'label'             => esc_html__( 'Description', 'kids-education-pro' ),
	'section'           => 'kids_education_pro_team',
	'type'              => 'textarea',
	'active_callback'	=> 'kids_education_pro_is_team_section_active',
) );


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'kids_education_pro_theme_options[team_description]', array(
		'selector'            => '#team-members p.sub-title',
		'render_callback'     => 'kids_education_pro_customize_partial_team_description',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Add no of team content type setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[team_content_type]', array(
	'default'           => $options['team_content_type'],
	'sanitize_callback' => 'kids_education_pro_sanitize_select',
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[team_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'kids-education-pro' ),
	'section'           => 'kids_education_pro_team',
	'type'              => 'select',
	'choices'			=> kids_education_pro_team_content_type(),
	'active_callback'	=> 'kids_education_pro_is_team_section_active',
) );

// Add no of team content setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[team_count]', array(
	'default'           => $options['team_count'],
	'validate_callback' => 'kids_education_pro_validate_no_of_team',
	'sanitize_callback' => 'absint',
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[team_count]', array(
	'label'             => esc_html__( 'No of Team', 'kids-education-pro' ),
	'section'           => 'kids_education_pro_team',
	'type'              => 'number',
	'input_attrs'		=> array (
		'min'	=> 1,
		'max'	=> 4,
		'style'	=> 'width:100px'
		),
	'active_callback'	=> 'kids_education_pro_is_team_section_demo_not_active',
) );

if ( class_exists( 'TP_Education' ) ) :
	for ( $i=1; $i <= $options['team_count']; $i++ ) { 
		// Add team post setting and control.
		$wp_customize->add_setting( 'kids_education_pro_theme_options[team_post_'. $i .']', array(
			'sanitize_callback' => 'absint'
		) );

		$wp_customize->add_control( 'kids_education_pro_theme_options[team_post_'. $i .']', array(
			'label'             => esc_html__( 'Post ID ', 'kids-education-pro' ). $i,
			'section'           => 'kids_education_pro_team',
			'type'              => 'number',
			'input_attrs'		=> array (
				'min'	=> 1,
				'style'	=> 'width:100px'
				),
			'active_callback'	=> 'kids_education_pro_is_team_section_post',
		) );
	}

	// Add no of team content type setting and control.
	$wp_customize->add_setting( 'kids_education_pro_theme_options[team_category]', array(
		'sanitize_callback' => 'absint',
	) );

	$wp_customize->add_control( new Kids_Education_Pro_Dropdown_Team_Taxonomies_Control( $wp_customize, 'kids_education_pro_theme_options[team_category]', array(
		'label'           => esc_html__( 'Select categories', 'kids-education-pro' ),
		'section'         => 'kids_education_pro_team',
		'type'            => 'dropdown-categories',
		'active_callback' => 'kids_education_pro_is_team_section_category', 
	) ) );

	if ( $options['site_design'] !== 'fifth-design' ) {
		
		// Add background property setting and control.
		$wp_customize->add_setting( 'kids_education_pro_theme_options[team_background_property]', array(
			'default'           => $options['team_background_property'],
			'sanitize_callback' => 'kids_education_pro_sanitize_select'
		) );

		$wp_customize->add_control( 'kids_education_pro_theme_options[team_background_property]', array(
			'label'           	=> esc_html__( 'Select background property', 'kids-education-pro' ),
			'section'         	=> 'kids_education_pro_team',
			'active_callback' 	=> 'kids_education_pro_is_team_section_demo_not_active',
			'type'				=> 'select',
			'choices'			=> array(
				'background_image' => esc_html__( 'Background Image', 'kids-education-pro' ),
				'background_color' => esc_html__( 'Background Color', 'kids-education-pro' ), 
			)
		) );

		// Add background image setting and control.
		$wp_customize->add_setting( 'kids_education_pro_theme_options[team_background_image]', array(
			'default'           => $options['team_background_image'],
			'sanitize_callback' => 'esc_url_raw'
		) );

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'kids_education_pro_theme_options[team_background_image]',
		    array(
				'label'           => esc_html__( 'Upload a background image', 'kids-education-pro' ),
				'description'     => esc_html__( 'Recommended background image size is 1920x420 px', 'kids-education-pro' ),
				'section'         => 'kids_education_pro_team',
				'active_callback' => 'kids_education_pro_is_team_background_property_image',
		   )
		));

		// Add background color setting and control.
		$wp_customize->add_setting( 'kids_education_pro_theme_options[team_background_color]', array(
			'default'           => $options['team_background_color'],
			'sanitize_callback' => 'sanitize_hex_color'
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kids_education_pro_theme_options[team_background_color]', array(
			'label'        => esc_html__( 'Background Color', 'kids-education-pro' ),
			'section'    => 'kids_education_pro_team',
			'active_callback' => 'kids_education_pro_is_team_background_property_color',
		) ) );
	}

endif;