<?php
/**
 * about section
 *
 * This is the template for the content of about section
 *
 * @package Theme Palace
 * @subpackage Kids Education Pro
 * @since Kids Education Pro 1.0
 */
if ( ! function_exists( 'kids_education_pro_add_about_section' ) ) :
  /**
   * Add about section
   *
   *@since Kids Education Pro 1.0
   */
  function kids_education_pro_add_about_section() {

    // Check if about is enabled on frontpage
    $about_enable = apply_filters( 'kids_education_pro_section_status', true, 'enable_about_content' );
    if ( true !== $about_enable ) {
      return false;
    }

    // Get about section details
    $section_details = array();
    $section_details = apply_filters( 'kids_education_pro_filter_about_section_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Render about section now.
    kids_education_pro_render_about_section( $section_details );
  }
endif;

$options = kids_education_pro_get_theme_options();
if ( $options['site_design'] == 'fifth-design' ) {
   add_action( 'kids_education_pro_primary_content', 'kids_education_pro_add_about_section', 30 );
}



if ( ! function_exists( 'kids_education_pro_get_about_section_details' ) ) :
  /**
   * about section details.
   *
   * @since Kids Education Pro 1.0
   * @param array $input about section details.
   */
  function kids_education_pro_get_about_section_details( $input ) {
    $options = kids_education_pro_get_theme_options();
    // about type
    $about_type  = $options['about_type'];

    $content = array();
    switch ( $about_type ) {
        case 'demo':
          $content['content']       = esc_html__( 'Find a Babysitter for your Kids during the holidays so you can shop, attend parties and wrap presents!', 'kids-education-pro' );
          $content['title']       = esc_html__( 'About Us', 'kids-education-pro' );
          $content['url']            = '#';
          $content['read_more_text'] = esc_html__( 'Read More', 'kids-education-pro' );

        break;

        case 'page':
          $id = null;
          if ( isset( $options[ 'about_page_id' ] ) ) {
              $id = $options[ 'about_page_id' ];
          }
          if ( ! empty( $id ) ) {
              $id = absint( $id );
          }
          // Bail if no valid pages are selected.
          if ( empty( $id ) ) {
              return $input;
          }

          $args = array(
              'post_type'      => 'page',
              'p'              => $id,
          );
        break;

        default:
        break;
    }
    if ( 'demo' != $about_type ) {
      // Fetch posts.
      $posts = get_posts( $args );

      if ( ! empty( $posts ) ) {

          foreach ( $posts as $key => $post ) {
            $page_id = $post->ID;

            $img_array = null;

                if ( has_post_thumbnail( $page_id ) ) {
                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $page_id ), 'large' );
                } else {
                        $img_array = array ( get_template_directory_uri() . '/assets/uploads/no-featured-image-1350x550.jpg' );
                }

                if ( isset( $img_array ) ) {
                    $content['img_array'] = $img_array;
                }
            $content['url']      = get_permalink( $page_id );
            $content['title']    = get_the_title( $page_id );
            $content['content']  = kids_education_pro_trim_content( $options['about_excerpt'], $post );
            $content['read_more_text'] = $options['about_learn_more_text'];
          }
      }
    }

    if ( ! empty( $content ) ) {
      $input = $content;
    }
    return $input;
  }
endif;
// about section content details.
add_filter( 'kids_education_pro_filter_about_section_details', 'kids_education_pro_get_about_section_details' );


if ( ! function_exists( 'kids_education_pro_render_about_section' ) ) :
  /**
   * Start about section
   *
   * @return string about content
   * @since Kids Education Pro 1.0
   *
   */
   function kids_education_pro_render_about_section( $content_details = array() ) {

        if ( empty( $content_details ) ) {
          return;
        } ?>
           <div id="medical-about-us" class="relative page-section">
              <div class="container">
                  <article class="has-post-thumbnail">
                      <div class="featured-image" style="background-image: url('<?php echo esc_url( $content_details['img_array'][0] ); ?>');">
                          <a href="<?php echo esc_url( $content_details['url'] ); ?>" class="post-thumbnail-link"></a>
                      </div><!-- .featured-image -->

                      <div class="entry-container">
                          <header class="entry-header">
                              <h2 class="entry-title"><a href="<?php echo esc_url( $content_details['url'] ); ?>"><?php echo esc_html( $content_details['title'] ); ?></a></h2>
                          </header>

                          <div class="entry-content">
                              <p><?php echo esc_html( $content_details['content'] ); ?></p>
                          </div><!-- .entry-content -->

                          <div class="medical-read-more">
                              <a href="<?php echo esc_url( $content_details['url'] ); ?>"><?php echo esc_html( $content_details['read_more_text'] ); ?></a>
                          </div><!-- .medical-read-more -->
                      </div><!-- .entry-container -->
                  </article>
              </div><!-- .container -->
          </div>
       
<?php 
    }
endif;