<?php
/**
 * counter section
 *
 * This is the template for the content of counter section
 *
 * @package Theme Palace
 * @subpackage Kids Education Pro
 * @since Kids Education Pro 1.0
 */
if ( ! function_exists( 'kids_education_pro_add_counter_section' ) ) :
  /**
   * Add counter section
   *
   *@since Kids Education Pro 1.0
   */
  function kids_education_pro_add_counter_section() {

    // Check if counter is enabled on frontpage
    $counter_enable = apply_filters( 'kids_education_pro_section_status', true, 'counter_enable' );
    if ( true !== $counter_enable ) {
      return false;
    }

    // Get counter section details
    $section_details = array();
    $section_details = apply_filters( 'kids_education_pro_filter_counter_section_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Render counter section now.
    kids_education_pro_render_counter_section( $section_details );
  }
endif;

$options = kids_education_pro_get_theme_options();
if ( in_array( $options['site_design'] , array( 'classic-design', 'modern-design', 'third-design' ) ) ) {
    add_action( 'kids_education_pro_primary_content', 'kids_education_pro_add_counter_section', 60 );
}



if ( ! function_exists( 'kids_education_pro_get_counter_section_details' ) ) :
  /**
   * counter section details.
   *
   * @since Kids Education Pro 1.0
   * @param array $input counter section details.
   */
  function kids_education_pro_get_counter_section_details( $input ) {
    $options = kids_education_pro_get_theme_options();

    // counter type
    $counter_content_type  = $options['counter_content_type'];

    $content = array();
    switch ( $counter_content_type ) {
      case 'demo':
        $icons = array( 'fa-child', 'fa-certificate', 'fa-book' , 'fa-rocket' );
        $title = array( 
          esc_html__( 'New Students', 'kids-education-pro' ), 
          esc_html__( 'Gold Medals', 'kids-education-pro' ), 
          esc_html__( 'Total Courses', 'kids-education-pro' ),
          esc_html__( 'Total Activities', 'kids-education-pro' ) 
        );
        $content_layout  = !empty( $options['counter_section_layout'] ) ? $options['counter_section_layout'] : 'four-columns'; // check counter section layout
        $no_of_demo_post = ( 'three-columns' == $content_layout ) ? 3 : 4; 
        
        for ( $i=0; $i< $no_of_demo_post; $i++ ) {
          $content[$i]['icon']   = $icons[ $i ];
          $content[$i]['title']  = $title[ $i ];
          $content[$i]['number'] = esc_html__( '999', 'kids-education-pro');
        }
        $input =  $content;
        return $input;
      break;

      case 'custom':
        $counter_count =  $options['counter_count'];

        for( $i = 1; $i <= $counter_count; $i++ ){
          if( !empty( $options['counter_icon_'.$i] ) || !empty( $options['counter_name_'.$i] ) || !empty( $options['counter_count_'.$i] ) ){

            $content[$i]['icon']   = !empty( $options['counter_icon_'.$i] ) ? $options['counter_icon_'.$i] : '';
            $content[$i]['title']  = !empty( $options['counter_name_'.$i] ) ? $options['counter_name_'.$i] : '';
            $content[$i]['number'] = !empty( $options['counter_count_'.$i] ) ? $options['counter_count_'.$i] : '';

          }
        }

        // Bail if no valid pages are selected.
        if ( !empty( $content ) ) {
          $input = $content;
        }
      return $input;
      break;

      default:
      break;
    }
  }
endif;
// counter section content details.
add_filter( 'kids_education_pro_filter_counter_section_details', 'kids_education_pro_get_counter_section_details' );


if ( ! function_exists( 'kids_education_pro_render_counter_section' ) ) :
  /**
   * Start counter section
   *
   * @return string counter content
   * @since Kids Education Pro 1.0
   *
   */
   function kids_education_pro_render_counter_section( $content_details = array() ) {

        if ( empty( $content_details ) ) {
          return;
        }

        $options             = kids_education_pro_get_theme_options();
        $counter_title       = !empty( $options['counter_section_title'] ) ? $options['counter_section_title']  : '';
        $counter_description = !empty( $options['counter_section_description'] ) ? $options['counter_section_description']  : '';
        $counter_layout      =  !empty( $options['counter_section_layout'] ) ? $options['counter_section_layout']  : 'four-columns';

        $background_property = $options['counter_background_property'];
        $background_css      = !empty( $options['counter_background_image'] ) ? 'style="background-image:url('.  esc_url( $options['counter_background_image'] ) .')"' : '';

        if( 'background_color' == $background_property ){
          $background_css = !empty( $options['counter_background_color'] ) ? 'style="background-color:'.  esc_attr( $options['counter_background_color'] ) .'"' : '';
        }

        ?>
        <section id="counter" class="page-section move-section-up background-image-properties os-animation" data-os-animation="fadeIn" <?php echo $background_css; ?>>
	        <div class="container">
		        <?php if( !empty( $counter_title) || !empty( $counter_description ) ) : ?>
		            <header class="entry-header">
		            	<?php if( !empty( $counter_title ) ){ ?>
		              		<h2 class="entry-title"><?php echo esc_html( $counter_title );?></h2>
		            	<?php } if( !empty( $counter_description ) ){ ?>
		              		<p class="sub-title"><?php echo esc_html( $counter_description );?></p>
		            	<?php } ?>              
		            </header><!-- .entry-header -->
		        <?php endif; ?>

	            <div class="entry-content">
	              	<div class="statscounts <?php echo esc_attr( $counter_layout );?>">
		                <?php foreach ($content_details as $content_detail ) : ?>
		                  	<div class="statwrap column-wrapper">
		                    <?php 
		                      	$output = '';
		                      	$output .= !empty( $content_detail['icon'] ) ? '<i class="fa '. esc_attr( $content_detail['icon'] ) .'"></i>' : '';
		                      	$output .= !empty( $content_detail['number'] ) ? '<h4 class="stat-count">'. absint( $content_detail['number'] ) .'</h4>' : '';
		                      	$output .= !empty( $content_detail['title'] ) ? '<h6>'. esc_html( $content_detail['title'] ) .'</h6>' : '';
		                      
		                      	echo $output; 
		                    ?>                      
		                  	</div><!-- .statwrap -->
		                <?php endforeach; ?>

	              	</div><!-- statscounts -->
	            </div><!-- .entry-content -->
	        </div><!-- .container -->
        </section><!-- #counter -->

<?php 
    }
endif;