<?php
/**
 * testimonial section
 *
 * This is the template for the content of testimonial section
 *
 * @package Theme Palace
 * @subpackage Kids Education Pro
 * @since Kids Education Pro 1.0
 */
if ( class_exists( 'TP_Education' ) ) :
    if ( ! function_exists( 'kids_education_pro_add_testimonial_section' ) ) :
        /**
        * Add testimonial section
        *
        *@since Kids Education Pro 1.0
        */
        function kids_education_pro_add_testimonial_section() {

            // Check if testimonial is enabled on frontpage
            $testimonial_enable = apply_filters( 'kids_education_pro_section_status', true, 'testimonial_enable' );
            if ( true !== $testimonial_enable ) {
                return false;
            }

            // Get testimonial section details
            $section_details = array();
            $section_details = apply_filters( 'kids_education_pro_filter_testimonial_section_details', $section_details );

            if ( empty( $section_details ) ) {
                return;
            }

            // Render testimonial section now.
            kids_education_pro_render_testimonial_section( $section_details );
        }
    endif;
    $options = kids_education_pro_get_theme_options();
    if ( in_array( $options['site_design'] , array( 'classic-design', 'modern-design', 'third-design' ) ) ) {
        add_action( 'kids_education_pro_primary_content', 'kids_education_pro_add_testimonial_section', 90 );
    }
    


    if ( ! function_exists( 'kids_education_pro_get_testimonial_section_details' ) ) :
        /**
        * testimonial section details.
        *
        * @since Kids Education Pro 1.0
        * @param array $input testimonial section details.
        */
        function kids_education_pro_get_testimonial_section_details( $input ) {
            $options = kids_education_pro_get_theme_options();

            // testimonial type
            $testimonial_content_type  = $options['testimonial_content_type'];

            $content = array();
            switch ( $testimonial_content_type ) {
                case 'demo':
                    for ( $i=1; $i<=3; $i++ ) {
                        $content[ $i ]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/client-0'.$i.'.png';
                        $content[$i]['url']          = '#';
                        $content[$i]['title']        = esc_html__( 'Jennifer Joel, UX Decor', 'kids-education-pro' );
                        $content[$i]['excerpt']      = esc_html__( 'Duis tincidunt lectus eget sem lobortis pellentesque vitae ac augue. Vestibulum pharetra libero ut.', 'kids-education-pro' );
                        $content[$i]['alt']          = esc_html__( 'testimonial Image', 'kids-education-pro' );
                    }
                break;

                case 'tp-testimonial':
                    $args = array(
                        'post_type'      => 'tp-testimonial',
                        'posts_per_page'  => absint( $options['testimonial_count'] ),
                    );
                break;

                default:
                break;
            }

            if ( 'demo' != $testimonial_content_type ) {
                // Fetch posts.
                $posts = get_posts( $args );

                if ( ! empty( $posts ) ) {

                    $i = 1;
                    foreach ( $posts as $key => $post ) {
                        $page_id = $post->ID;
                        $img_array = null;
                        if ( has_post_thumbnail( $page_id ) ) {
                            $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'thumbnail' );
                        } else {
                            $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-300x300.png';
                        }

                        if ( isset( $img_array ) ) {
                            $content[$i]['img_array'] = $img_array;
                        }

                        $content[$i]['id']       = $page_id;
                        $content[$i]['url']      = get_permalink( $page_id );
                        $content[$i]['title']    = get_the_title( $page_id );
                        $content[$i]['excerpt']  = kids_education_pro_trim_content( $options['testimonial_excerpt'], $post  );
                        $content[$i]['alt']      = get_the_title( $page_id );

                        $i++;
                    }
                }
            }

            if ( ! empty( $content ) ) {
                $input = $content;
            }
            return $input;
        }
    endif;
    // testimonial section content details.
    add_filter( 'kids_education_pro_filter_testimonial_section_details', 'kids_education_pro_get_testimonial_section_details' );


    if ( ! function_exists( 'kids_education_pro_render_testimonial_section' ) ) :
        /**
        * Start testimonial section
        *
        * @return string testimonial content
        * @since Kids Education Pro 1.0
        *
        */
        function kids_education_pro_render_testimonial_section( $content_details = array() ) {
            $options                  = kids_education_pro_get_theme_options();
            $testimonial_content_type = $options['testimonial_content_type'];
            $testimonial_dragable     = ( $options['testimonial_dragable'] == true ) ? 'true' : 'false';
            $testimonial_pager        = ( $options['testimonial_pager'] == true ) ? 'true' : 'false';
            $testimonial_pauseonhover = ( $options['testimonial_pauseonhover'] == true ) ? 'true' : 'false';

            $background_property = $options['testimonial_background_property'];
            $background_css      = !empty( $options['testimonial_background_image'] ) ? 'style="background-image:url('.  esc_url( $options['testimonial_background_image'] ) .')"' : '';

            if( 'background_color' == $background_property ){
                $background_css = !empty( $options['testimonial_background_color'] ) ? 'style="background-color:'.  esc_attr( $options['testimonial_background_color'] ) .'"' : '';
            }

            if ( empty( $content_details ) ) {
                return;
            } ?>
            <section id="client-testimonial-slider" class="page-section move-section-up background-image-properties os-animation" data-os-animation="fadeIn" <?php echo $background_css; ?>>
                <div class="container">
                    <div class="entry-content regular" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1500, "pauseOnHover": <?php echo $testimonial_pauseonhover; ?>, "draggable": <?php echo $testimonial_dragable; ?>, "dots": <?php echo $testimonial_pager; ?>, "arrows":false, "autoplay": true, "fade": false }'>
                        <?php foreach ( $content_details as $content_detail ) :?>
                            <div class="slider-item">
                                <div class="client-image">
                                    <a href="<?php echo esc_url( $content_detail['url'] ); ?>">
                                        <img src="<?php echo esc_url( $content_detail['img_array'][0] ); ?>" alt="<?php echo esc_attr( $content_detail['alt'] ); ?>">
                                    </a>
                                </div><!-- .client-image -->
                                <blockquote>
                                    <?php echo esc_html( $content_detail['excerpt'] ); ?>
                                </blockquote>
                                <p class="name"><a href="<?php echo esc_url( $content_detail['url'] ); ?>"><?php echo '- ' . esc_html( $content_detail['title'] ); ?></a></p>
                                <div class="star-rating">
                                <?php 
                                if ( $testimonial_content_type == 'post' ) {
                                    tp_testimonial_rating( $content_detail['id'] ); 
                                } else {
                                    for ( $i=1; $i <=5 ; $i++) { 
                                        echo '<i class="fa fa-star"></i>';
                                    }
                                } ?>
                                </div><!-- .star-rating -->
                            </div><!-- .slider-item -->
                        <?php endforeach; ?>   
                    </div><!-- .entry-content -->
                </div><!-- .container -->
            </section><!-- #client-testimonial -->
        <?php 
        }
    endif;
endif;