<?php
/**
 * Kids Educationwidgets inclusion
 *
 * This is the template that includes all custom widgets of Theme Palace
 *
 * @package Theme Palace
 * @subpackage Kids Education Pro
 * @since Kids Education Pro 1.0
 */

if ( ! class_exists( 'Kids_Education_Pro_Popular_Post' ) ) :

     
    class Kids_Education_Pro_Popular_Post extends WP_Widget {
        /**
         * Sets up the widgets name etc
         */
        public function __construct() {
            $tp_widget_popular_post = array(
                'classname'   => 'kids_education_pro_popular_post',
                'description' => esc_html__( 'Retrive top viewed posts.', 'kids-education-pro' ),
            );
            parent::__construct( 'kids_education_pro_popular_post', esc_html__( 'TP : Popular Posts', 'kids-education-pro' ), $tp_widget_popular_post );
        }

        /**
         * Outputs the content of the widget
         *
         * @param array $args
         * @param array $instance
         */
        public function widget( $args, $instance ) {
            // outputs the content of the widget
            if ( ! isset( $args['widget_id'] ) ) {
                $args['widget_id'] = $this->id;
            }

            $tp_title  = ( ! empty( $instance['title'] ) ) ? ( $instance['title'] ) : esc_html__( 'Popular', 'kids-education-pro' );
            $tp_number = isset( $instance['number'] ) ? absint( $instance['number'] ) : 3;

            echo $args['before_widget'];
                if ( ! empty( $tp_title ) ) {
                    echo $args['before_title'] . esc_html( $tp_title ) . $args['after_title'];
                }
            $popular_args = array(
                'post_type'         => 'post',
                'posts_per_page'    => $tp_number,
                'meta_key'          => 'post_views_count',
                'orderby'           => 'post_views_count'
                );

            $wp_query = get_posts( $popular_args );
            echo '<ul>';
            foreach ( $wp_query as $post ) :
            ?>
            <li class="has-post-thumbnail">
                <a href="<?php the_permalink( $post->ID ); ?>" class="post-thumbnail">
                    <?php 
                    if ( has_post_thumbnail( $post->ID ) ) :
                        $image = get_the_post_thumbnail( $post->ID, $size = 'thumbnail', array( 'alt' => esc_attr( get_the_title( $post->ID ) ) ) );
                        echo $image;
                    else: 
                        $image = '<img src="'. get_template_directory_uri() .'/assets/uploads/no-featured-image-300x300.png" alt="'.esc_attr__( 'popular-post', 'kids-education-pro' ) .'">';
                        echo $image;
                    endif; 
                    ?>
                </a>
                <div class="post-content">
                    <a href="<?php the_permalink( $post->ID ); ?>"><?php echo esc_html( $post->post_title ); ?></a>
                    <time><?php echo esc_html( get_the_date( '', $post->ID ) ); ?></time>
                </div><!-- .post-content -->
            </li>

            <?php
            endforeach;
            echo '</ul>';
            echo $args['after_widget'];
        }

        /**
         * Outputs the options form on admin
         *
         * @param array $instance The widget options
         */
        public function form( $instance ) {
            $tp_title      = isset( $instance['title'] ) ? ( $instance['title'] ) : esc_html__( 'Popular', 'kids-education-pro' );
            $tp_number     = isset( $instance['number'] ) ? absint( $instance['number'] ) : 3;
           ?>

           <p>
               <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'kids-education-pro' ); ?></label>
               <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('title') ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $tp_title ); ?>" />
           </p>

           <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>"><?php esc_html_e( 'Number of posts to show:', 'kids-education-pro' ); ?></label>
            <input class="tiny-text" id="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'number' ) ); ?>" type="number" step="1" min="1" max="7" value="<?php echo absint( $tp_number ); ?>" size="3" />
           </p>

           <?php
        }

        /**
        * Processing widget options on save
        *
        * @param array $new_instance The new options
        * @param array $old_instance The previous options
        */
        public function update( $new_instance, $old_instance ) {
            // processes widget options to be saved
            $instance           = $old_instance;
            $instance['title']  = sanitize_text_field( $new_instance['title'] );
            $instance['number'] = (int) $new_instance['number'];
           
            return $instance;
        }
    }
endif;


function kids_education_pro_register_popular_post() {
   register_widget( 'Kids_Education_Pro_Popular_Post' );
}
add_action( 'widgets_init', 'kids_education_pro_register_popular_post' );
